==> deepin-calculator_6.0.0.tar.xz: BUILD/translations/deepin-calculator_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>표현식 오류</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>모든 메모리 지우기</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>기록 지우기</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>모두 선택</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>계산기</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard and scientific modes.</source>
        <translation>계산기는 표준 및 공학용 모드를 지원하는 사용하기 쉬운 데스크탑 계산기입니다.</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>표준</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>공학용</translation>
    </message>
    <message>
        <source>History</source>
        <translation>기록</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>모드</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>메모리 항목 지우기</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>모든 메모리 지우기</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>메모리 재호출</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>메모리 항목에 추가</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>메모리 추가</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>메모리 항목에서 빼기</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>메모리 빼기</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>메모리 저장</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>메모리</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>메모리 항목 지우기</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>메모리 항목에 추가</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>메모리 항목에서 빼기</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>메모리에 저장된 것이 없습니다</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>계산기</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>표현식 오류</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>기록</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>메모리</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>표현식 오류</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>기록 없음</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
</context>
</TS>

==> deepin-calculator_6.5.9.tar.xz: BUILD/translations/deepin-calculator_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>표현식 오류</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>모든 메모리 지우기</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>기록 지우기</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>모두 선택</translation>
    </message>
    <message>
        <source>Use thousands separator</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use ten-thousands separator</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Undo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>계산기</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>표준</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>공학용</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>모드</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Programmer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>메모리 항목 지우기</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>모든 메모리 지우기</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>메모리 재호출</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>메모리 항목에 추가</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>메모리 추가</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>메모리 항목에서 빼기</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>메모리 빼기</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>메모리 저장</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>메모리</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>메모리 항목 지우기</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>메모리 항목에 추가</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>메모리 항목에서 빼기</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>메모리에 저장된 것이 없습니다</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>표현식 오류</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Logical shift</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Circular shift</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Logical shift</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Circular shift</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>계산기</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>표현식 오류</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>기록</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>메모리</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>표현식 오류</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>기록 없음</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
</context>
</TS>
